pub trait MigrationConnection: Connection {
// Required method
fn setup(&mut self) -> QueryResult<usize>;
}Expand description
A trait indicating that a connection could be used to manage migrations
Only custom backend implementations need to think about this trait
Required Methods
Sourcefn setup(&mut self) -> QueryResult<usize>
fn setup(&mut self) -> QueryResult<usize>
Setup the following table:
diesel::table! {
__diesel_schema_migrations(version) {
version -> Text,
/// defaults to `CURRENT_TIMESTAMP`
run_on -> Timestamp,
}
}Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementors
impl MigrationConnection for SqliteConnection
Available on crate feature
sqlite only.